## THIS IS A TOPSIS PROGRAM IN PYTHON

    ================       

    Submitted By: **Yubhav Seth**

    ================

    ## Run the program through command line as:

    ### Usages:
    ```
    >>>python topsis.py <InputDataFile> <Weights> <Impacts> <ResultFileName>
    ```

    ### Example:
    ```
    >>>python topsis.py inputfile.csv “1,1,1,2” “+,+,-,+” result.csv
    ```

    ================